import { Component, OnInit } from '@angular/core';
import { FormGroup, FormBuilder, Validators } from '@angular/forms';
import { MatCardModule } from '@angular/material/card';
import { Router } from '@angular/router';
import { LoginService } from '../services/login.service';
import { Userlogin } from '../Userlogin';

@Component({
  selector: 'app-login',
  templateUrl: './login.component.html',
  styleUrls: ['./login.component.css']
})
export class LoginComponent implements OnInit {

  loginForm: any;
  invalidLogin: boolean = false;
  message: any;

  constructor(private formBuilder: FormBuilder, private router: Router, private loginService: LoginService) { }

  ngOnInit(): void {
    this.loginForm = this.formBuilder.group({
      login: ['', Validators.compose([Validators.required])],
      password: ['', Validators.required]
    })
  }
  
  onSubmit() {
    
    console.log(this.loginForm.value);


    if(this.loginForm.invalid)
    {
      return;
    }

    const logindata = {
      login: this.loginForm.controls.login.value,
      password: this.loginForm.controls.password.value
    };

    this.loginService.login(logindata).subscribe((data: any) => {
      console.log(data);
      this.message = data.message;
    
    if(data.token) {
      window.localStorage.setItem('token', data.token);
      this.router.navigate(['dash']);
    }
    else
    {
      this.invalidLogin = true;
      alert(data.message);
    }
  });
}
}
